# PySilero

## Silero VAD

See [Silero VAD](https://github.com/snakers4/silero-vad).

### Denoiser

See [RnNoise](https://github.com/werman/noise-suppression-for-voice).

### Python Usage

```bash
$ pip install pysilero
$ pysilero audio.wav
```
